// PoVRay 3.6 Scene File " ... .pov"
// created by   ...  
// Date:   ...
//------------------------------------------------------------------------
#version 3.5;
global_settings {  assumed_gamma 1.0 }
#default{ finish{ ambient 0.1 diffuse 0.9 }} 
//------------------------------------------------------------------------
#include "colors.inc"
#include "textures.inc"
#include "glass.inc"
#include "metals.inc"
#include "golds.inc"
#include "stones.inc"
#include "woods.inc"
#include "shapes.inc"
#include "shapes2.inc"
#include "functions.inc"
#include "math.inc"
#include "transforms.inc"
//------------------------------------------------------------------------
#declare Camera_0 = camera {/*ultra_wide_angle*/ angle 15      // front view
                            location  <0.0 , 1.0 ,-10.0>
                            right     x*image_width/image_height
                            look_at   <0.0 , 1.0 , 0.0>}
#declare Camera_1 = camera {/*ultra_wide_angle*/ angle 14   // diagonal view
                            location  <5.0 , 5.0 ,-5.0>
                            right     x*image_width/image_height
                            look_at   <0.0 , 0.15 , 0.0>}
#declare Camera_2 = camera {/*ultra_wide_angle*/ angle 20  //right side view
                            location  <3.0 , 1.0 , 0.0>
                            right     x*image_width/image_height
                            look_at   <0.0 , 1.0 , 0.0>}
#declare Camera_3 = camera {/*ultra_wide_angle*/ angle 20        // top view
                            location  <0.0 , 3.0 ,-0.001>
                            right     x*image_width/image_height
                            look_at   <0.0 , 1.0 , 0.0>}
#declare Camera_4 = camera {/*ultra_wide_angle*/ angle 15      // front view
                            location  <1.0 , 1.0 ,-10.0>
                            right     x*image_width/image_height
                            look_at   <1.0 , 1.0 , 0.0>}
                            
camera{Camera_1}
//------------------------------------------------------------------------
// sun -------------------------------------------------------------------
light_source{<1500,2500,-2500> color White}
// sky -------------------------------------------------------------------
sky_sphere{ pigment{ gradient <0,1,0>
                     color_map{ [0   color rgb<1,1,1>         ]//White
                                [0.4 color rgb<0.14,0.14,0.56>]//~Navy
                                [0.6 color rgb<0.14,0.14,0.56>]//~Navy
                                [1.0 color rgb<1,1,1>         ]//White
                              }
                     scale 2 }
           } // end of sky_sphere 
//------------------------------------------------------------------------

//------------------------------ the Axes --------------------------------
//------------------------------------------------------------------------
#macro Axis_( AxisLen, Dark_Texture,Light_Texture) 
 union{
    cylinder { <0,-AxisLen,0>,<0,AxisLen,0>,0.05
               texture{checker texture{Dark_Texture } 
                               texture{Light_Texture}
                       translate<0.1,0,0.1>}
             }
    cone{<0,AxisLen,0>,0.2,<0,AxisLen+0.7,0>,0
          texture{Dark_Texture}
         }
     } // end of union                   
#end // of macro "Axis()"
//------------------------------------------------------------------------
#macro AxisXYZ( AxisLenX, AxisLenY, AxisLenZ, Tex_Dark, Tex_Light)
//--------------------- drawing of 3 Axes --------------------------------
union{
#if (AxisLenX != 0)
 object { Axis_(AxisLenX, Tex_Dark, Tex_Light)   rotate< 0,0,-90>}// x-Axis
 text   { ttf "arial.ttf",  "x",  0.15,  0  texture{Tex_Dark} 
          scale 0.5 translate <AxisLenX+0.05,0.4,-0.10>}
#end // of #if 
#if (AxisLenY != 0)
 object { Axis_(AxisLenY, Tex_Dark, Tex_Light)   rotate< 0,0,  0>}// y-Axis
 text   { ttf "arial.ttf",  "y",  0.15,  0  texture{Tex_Dark}    
           scale 0.5 translate <-0.75,AxisLenY-0.30,-0.10>}
#end // of #if 
#if (AxisLenZ != 0)
 object { Axis_(AxisLenZ, Tex_Dark, Tex_Light)   rotate<90,0,  0>}// z-Axis
 text   { ttf "arial.ttf",  "z",  0.15,  0  texture{Tex_Dark}
               scale 0.5 translate <-0.75,0.2,AxisLenZ+0.10>}
#end // of #if 
} // end of union
#end// of macro "AxisXYZ( ... )"
//------------------------------------------------------------------------

#declare Texture_A_Dark  = texture {
                               pigment{ color rgb<1,0.45,0>}
                               finish { phong 1}
                             }
#declare Texture_A_Light = texture { 
                               pigment{ color rgb<1,1,1>}
                               finish { phong 1}
                             }

object{ AxisXYZ( 4.5, 3.5, 5, Texture_A_Dark, Texture_A_Light) scale 0.25}
//-------------------------------------------------- end of coordinate axes


// ground -----------------------------------------------------------------
//---------------------------------<<< settings of squared plane dimensions
#declare RasterScale = 0.10;
#declare RasterHalfLine  = 0.025;  
#declare RasterHalfLineZ = 0.025; 
//-------------------------------------------------------------------------
#macro Raster(RScale, HLine) 
       pigment{ gradient x scale RScale
                color_map{[0.000   color rgbt<1,1,1,0>*0.6]
                          [0+HLine color rgbt<1,1,1,0>*0.6]
                          [0+HLine color rgbt<1,1,1,1>]
                          [1-HLine color rgbt<1,1,1,1>]
                          [1-HLine color rgbt<1,1,1,0>*0.6]
                          [1.000   color rgbt<1,1,1,0>*0.6]} }
 #end// of Raster(RScale, HLine)-macro    
//-------------------------------------------------------------------------
    

plane { <0,1,0>, 0    // plane with layered textures
        texture { pigment{color White*1.1}
                  finish {ambient 0.45 diffuse 0.85}}
        texture { Raster(RasterScale,RasterHalfLine ) rotate<0,0,0> }
        texture { Raster(RasterScale,RasterHalfLineZ) rotate<0,90,0>}
        rotate<0,0,0>
      }
//------------------------------------------------ end of squared plane XZ

//--------------------------------------------------------------------------
//---------------------------- objects in scene ----------------------------
//--------------------------------------------------------------------------
   
/*
Variablen:
Clock von 0..1 mit 0.05 increment
Wa: Drehwinkel   Schwungrad von 0 bis 2 Pi= Clock *2; 
Xa: X-Pos        Schwungrad = COS(PI()*W);
ya: y-Pos        Schwungrad = SIN(PI()*W);
Xf: X-Pos        Zylinderdrehpunkt = const;
yf: y-Pos        Zylinderdrehpunkt = const;      
Xr: X-Diff       = Xf-Xa
Yr: Y-Diff       = Yf-Ya
Wr: Winkel Zyl. im Bogenmass = atan(yr/xr)
Wf: Winkel Zyl. in Grad      = Wr /(1/180)
Kl: Lnge Kolben
Kd: Durchmesser Kolben
*/   

#declare Wa  = clock *2;   
#declare Ya  = sin(pi*Wa);
#declare Xa  = cos(pi*Wa);
#declare Yf  = 0;
#declare Xf  = 6;
#declare Yr  = Yf-Ya;
#declare Xr  = Xf-Xa;
#declare Wr  = atan(Yr/Xr);   
#declare Wf  = (180/pi) * Wr;
#declare Kl  = 4.5;
#declare Kd  = 0.1;
   
#debug concat("Value Wa is:",str(Wa,8,5),"\n")
#debug concat("Value Ya is:",str(Ya,8,5),"\n")
#debug concat("Value Xa is:",str(Xa,8,5),"\n")
#debug concat("Value Yr is:",str(Yr,8,5),"\n")
#debug concat("Value Xr is:",str(Xr,8,5),"\n")
#debug concat("Value Wf is:",str(Wf,8,5),"\n")
   
union{                             
union{
  cylinder{ <0,0,-0.03>,<0,0,-0.01>,.11 texture{pigment {color Red}}}                      // Schwungrad rechts
  cylinder{ <0,0, 0.03>,<0,0, 0.01>,.11 texture{pigment {color Red}}}                      // Schwungrad links
  cylinder{ <0,0,-0.15>,<0,0,-0.02>,.01 texture{pigment {color Green}}}                    // Welle rechts
  cylinder{ <0,0, 0.15>,<0,0, 0.02>,.01 texture{pigment {color Green}}}                    // Welle links
}
cylinder{ <Xa/10,Ya/10,-0.032>,<Xa/10,Ya/10,0.032>,.01 texture{pigment {color Green}}}     // Kurbelzapfen
cylinder{ <Xf/10,Yf/10,-0.032>,<Xf/10,Yf/10,0.032>,.01 texture{pigment {color Green}}}     // Zylinderdrehpunkt


cylinder{                                                                                  // Kolben      
        <0,0,0>,<Kl/10,0,0>,Kd /10 texture{pigment {color Blue}}
        rotate z*Wf
        translate x*(Xa/10)
        translate y*(Ya/10)
}             

union{
  difference {                                                                             // Zylinder 
    #declare Bw = (Kd +0.05) /10;
    box {<0,Bw,Bw>,<-0.28,-Bw,-Bw> }                                                       // Block
    union {
      cylinder{ <0,0,0>,<-0.3,0,0>, (Kd /10) * 1.1 }                                       // Bohrung                                   
      //box {<0,Bw*0.8, Bw-0.1>,<-0.28,-Bw*0.8,0>}                                         // Aufgeschnitten
      cylinder{ <-0.03,0,-2>,<-0.03,0,2>,.01 }                                             // Steuerbohrung
    }  
    rotate z*Wf
    translate x*(Xf/10)    
  } 
  texture { pigment {color <1,1,0,.5> }}
}
  
  scale 2                                                    
  translate y*.3 
  
}